==> ksni-technical-test-1.1.9.tgz: package/README.md <==
# ksni-technical-test

<p align="center">
<img src="https://img.shields.io/github/contributors/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/issues/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/stars/Yunnie-pin/Technical-Test-KSNI?style=flat-square"> 
<img src="https://img.shields.io/github/forks/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/last-commit/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/languages/code-size/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/license/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
</p>

## About

ksni-techniclal test is a simple project to test the technical skills of a candidate. The project is a simple web application that allows users to make dinamic form and view the details
. The project is built using Vite and VueJs.

This is a [Vue.js](https://vuejs.org/) project bootstrapped with vitejs 

## Installation

```bash
npm install ksni-technical-test 
```

## Configuration

#### Example Syntax

* First, run the development server:

```bash
npm run dev
# or
yarn dev
# or
pnpm dev
# or
bun dev
```

* Open [http://localhost:3000](http://localhost:3000) with your browser to see the result.
* You can start editing the page by modifying `app/page.tsx`. The page auto-updates as you edit the file.
* This project uses [`next/font`](https://nextjs.org/docs/basic-features/font-optimization) to automatically optimize and load Inter, a custom Google Font.


### Contributors
  Open [Contributor](https://github.com/Yunnie-pin/Technical-Test-KSNI/graphs/contributors)

## License

MIT

==> ksni-technical-test-1.1.10.tgz: package/README.md <==
# ksni-technical-test

<p align="center">
<img src="https://img.shields.io/github/contributors/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/issues/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/stars/Yunnie-pin/Technical-Test-KSNI?style=flat-square"> 
<img src="https://img.shields.io/github/forks/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/last-commit/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/languages/code-size/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
<img src="https://img.shields.io/github/license/Yunnie-pin/Technical-Test-KSNI?style=flat-square">
</p>

## About

ksni-techniclal test is a simple project to test the technical skills of a candidate. The project is a simple web application that allows users to make dinamic form and view the details
. The project is built using Vite and VueJs.

This is a [Vue.js](https://vuejs.org/) project bootstrapped with vitejs 

## Installation

```bash
npm install ksni-technical-test 
```

## Configuration

#### Example Syntax

* First, run the development server:

```bash
npm run dev
# or
yarn dev
# or
pnpm dev
# or
bun dev
```

* Open [http://localhost:3000](http://localhost:3000) with your browser to see the result.
* You can start editing the page by modifying `src`. The page auto-updates as you edit the file.


### Contributors
  Open [Contributor](https://github.com/Yunnie-pin/Technical-Test-KSNI/graphs/contributors)

## License

MIT
